@@ -1,4 +1,6 @@
 import json
+from datetime import datetime
+from typing import Optional
 
 from apiclient_pydantic import serialize_all_methods, serialize_response
 from pydantic.json import pydantic_encoder
@@ -30,6 +32,16 @@ from authomize.rest_api_client.generated.schemas import (
     NewUserResponseSchema,
     NewUsersListRequestSchema,
     RestApiConnectorListSchema,
+    SearchAccountsAssociationsListResponseSchema,
+    SearchAssetsInheritanceListResponseSchema,
+    SearchAssetsListResponseSchema,
+    SearchGroupingResponseSchema,
+    SearchGroupingsAssociationsListResponseSchema,
+    SearchIdentitiesListResponseSchema,
+    SearchPermissionResponseSchema,
+    SearchPrivilegeGrantsListResponseSchema,
+    SearchPrivilegesListResponseSchema,
+    SearchUsersListResponseSchema,
     SubmitResponse,
 )
 
@@ -101,6 +113,23 @@ class Client(BaseClient):
             raise ValueError('Missing app_id')
         return self.http_delete(url=f'/v2/apps/{app_id}/data')
 
+    def search_users(
+        self,
+        app_id: str,
+        start_date: Optional[datetime] = None,
+    ) -> SearchUsersListResponseSchema:
+        if not app_id:
+            raise ValueError('Missing app_id')
+        params = dict(
+            start_date=start_date,
+        )
+        return self.http_get(
+            url=f'/v2/apps/{app_id}/accounts/users',
+            params={
+                **params,
+            },
+        )
+
     def create_users(
         self,
         app_id: str,
@@ -116,6 +145,23 @@ class Client(BaseClient):
             ),
         )
 
+    def search_groupings(
+        self,
+        app_id: str,
+        start_date: Optional[datetime] = None,
+    ) -> SearchGroupingResponseSchema:
+        if not app_id:
+            raise ValueError('Missing app_id')
+        params = dict(
+            start_date=start_date,
+        )
+        return self.http_get(
+            url=f'/v2/apps/{app_id}/access/grouping',
+            params={
+                **params,
+            },
+        )
+
     def create_groupings(
         self,
         app_id: str,
@@ -131,6 +177,23 @@ class Client(BaseClient):
             ),
         )
 
+    def search_permissions(
+        self,
+        app_id: str,
+        start_date: Optional[datetime] = None,
+    ) -> SearchPermissionResponseSchema:
+        if not app_id:
+            raise ValueError('Missing app_id')
+        params = dict(
+            start_date=start_date,
+        )
+        return self.http_get(
+            url=f'/v2/apps/{app_id}/access/permissions',
+            params={
+                **params,
+            },
+        )
+
     def create_permissions(
         self,
         app_id: str,
@@ -146,6 +209,23 @@ class Client(BaseClient):
             ),
         )
 
+    def search_privileges(
+        self,
+        app_id: str,
+        start_date: Optional[datetime] = None,
+    ) -> SearchPrivilegesListResponseSchema:
+        if not app_id:
+            raise ValueError('Missing app_id')
+        params = dict(
+            start_date=start_date,
+        )
+        return self.http_get(
+            url=f'/v2/apps/{app_id}/privileges',
+            params={
+                **params,
+            },
+        )
+
     def create_privileges(
         self,
         app_id: str,
@@ -161,6 +241,23 @@ class Client(BaseClient):
             ),
         )
 
+    def search_privileges_grants(
+        self,
+        app_id: str,
+        start_date: Optional[datetime] = None,
+    ) -> SearchPrivilegeGrantsListResponseSchema:
+        if not app_id:
+            raise ValueError('Missing app_id')
+        params = dict(
+            start_date=start_date,
+        )
+        return self.http_get(
+            url=f'/v2/apps/{app_id}/privileges/grants',
+            params={
+                **params,
+            },
+        )
+
     def create_privileges_grants(
         self,
         app_id: str,
@@ -176,6 +273,23 @@ class Client(BaseClient):
             ),
         )
 
+    def search_accounts_association(
+        self,
+        app_id: str,
+        start_date: Optional[datetime] = None,
+    ) -> SearchAccountsAssociationsListResponseSchema:
+        if not app_id:
+            raise ValueError('Missing app_id')
+        params = dict(
+            start_date=start_date,
+        )
+        return self.http_get(
+            url=f'/v2/apps/{app_id}/association/accounts',
+            params={
+                **params,
+            },
+        )
+
     def create_accounts_association(
         self,
         app_id: str,
@@ -191,6 +305,23 @@ class Client(BaseClient):
             ),
         )
 
+    def search_groupings_association(
+        self,
+        app_id: str,
+        start_date: Optional[datetime] = None,
+    ) -> SearchGroupingsAssociationsListResponseSchema:
+        if not app_id:
+            raise ValueError('Missing app_id')
+        params = dict(
+            start_date=start_date,
+        )
+        return self.http_get(
+            url=f'/v2/apps/{app_id}/association/groupings',
+            params={
+                **params,
+            },
+        )
+
     def create_groupings_association(
         self,
         app_id: str,
@@ -206,6 +337,23 @@ class Client(BaseClient):
             ),
         )
 
+    def search_assets(
+        self,
+        app_id: str,
+        start_date: Optional[datetime] = None,
+    ) -> SearchAssetsListResponseSchema:
+        if not app_id:
+            raise ValueError('Missing app_id')
+        params = dict(
+            start_date=start_date,
+        )
+        return self.http_get(
+            url=f'/v2/apps/{app_id}/assets',
+            params={
+                **params,
+            },
+        )
+
     def create_assets(
         self,
         app_id: str,
@@ -221,6 +369,23 @@ class Client(BaseClient):
             ),
         )
 
+    def search_assets_inheritance(
+        self,
+        app_id: str,
+        start_date: Optional[datetime] = None,
+    ) -> SearchAssetsInheritanceListResponseSchema:
+        if not app_id:
+            raise ValueError('Missing app_id')
+        params = dict(
+            start_date=start_date,
+        )
+        return self.http_get(
+            url=f'/v2/apps/{app_id}/assets/inheritance',
+            params={
+                **params,
+            },
+        )
+
     def create_assets_inheritance(
         self,
         app_id: str,
@@ -236,6 +401,23 @@ class Client(BaseClient):
             ),
         )
 
+    def search_identities(
+        self,
+        app_id: str,
+        start_date: Optional[datetime] = None,
+    ) -> SearchIdentitiesListResponseSchema:
+        if not app_id:
+            raise ValueError('Missing app_id')
+        params = dict(
+            start_date=start_date,
+        )
+        return self.http_get(
+            url=f'/v2/apps/{app_id}/identities',
+            params={
+                **params,
+            },
+        )
+
     def create_identities(
         self,
         app_id: str,
